#!/usr/bin/env python3
import requests
import configparser
import file_config.upload as upload
import os
import file_config.space as space


url_config = configparser.ConfigParser()
# 脚本当前的绝对路径
current_path = os.path.abspath(os.path.dirname(__file__))
url_config.read(current_path + '/server_config.ini')
login_url = url_config['server']['login_url']
upload_url = url_config['server']['upload_url']
list_url = url_config['server']['list_url']
create_url = url_config['server']['create_url']


def ctl():
    while True:
        username = input("请输入用户名(exit-退出):").strip()
        if username == 'exit':
            return
        password = input("请输入密码(exit-退出):").strip()
        if password == 'exit':
            return
        data = {'username': username, 'password': password}
        response = requests.post(login_url, data=data)
        data = response.json()

        if data['code'] == 0:
            user_id = data['data']['id']
            print("用户：" + username + "登录成功")
            while True:
                option_other = input("请输入你的选择(help —— 帮助): ").strip()
                if len(option_other.split()) > 0:
                    if option_other.split()[0] == "create":
                        space.create(create_url, user_id, option_other)
                    elif option_other.split()[0] == "upload":
                        upload.execute(user_id, upload_url, option_other)
                    elif option_other == "list":
                        space.get_list(list_url, user_id)
                    elif option_other == "help":
                        space.space_help()
                    elif option_other == "exit":
                        print("Exit Skyctl")
                        return
        else:
            print('用户名或密码错误,请重新登录')


ctl()



#!/usr/bin/env python3
import configparser

import requests
import os
import tarfile

# url = "http://192.168.3.146:48080/app-api/uctools/file/upload"  # 服务器地址
home = os.path.expanduser('~').replace('\\', '/')


# aws = home + "/.aws"
# image = home + "/image"
def test():
    current_working_directory = os.getcwd()
    current_path = os.path.abspath(os.path.dirname(__file__))
    print("当前工作目录：", current_working_directory)
    print("当前绝对路径：", current_path)


test()

# def is_directory_empty(directory):
#     return not os.listdir(directory)
#
#
# def upload_file(path, upload_type):
#     # 遍历目标目录所有文件以及目录
#     for root_dir, branch_dir, root_file_names in os.walk(path):
#
#         for file_name in root_file_names:
#             file_path = os.path.join(root_dir, file_name).replace('\\', '/')
#             # 元组列表形式
#             if is_directory_empty(root_dir):
#                 print("文件夹: ", root_dir, "为空")
#
#             else:
#                 files = [('file', open(file_path, 'rb'))]
#                 print("文件夹: ", root_dir, "不为空")
#                 print(file_path)
#                 print(root_dir.replace('\\', '/'))
#                 data = {'type': upload_type, 'path': root_dir.replace('\\', '/')}  # 类型aws = 1
#                 response = requests.post(url, files=files, data=data)
#                 print(response.text)
#
#
# def execute():
#     if os.path.exists(aws) and os.path.isdir(aws):
#         upload_file(aws, 1)
#     else:
#         print("文件夹不存在")



import requests


def get_list(url, user_id):
    data = {'userId': user_id}
    response = requests.post(url, data=data)
    res = response.json()
    space_list = res['data']
    str_name = ''
    for space in space_list:
        str_name += space + ' '
    print(str_name)


def create(url, user_id, space_name: str):
    print(len(space_name.split()))
    if not len(space_name.split()) == 2:
        print('请按正确的格式输入')
        return
    space = space_name.split()[1]
    data = {'createSource': user_id, 'nameSpace': space}
    response = requests.post(url, data=data)
    res = response.json()
    if res['code'] == 1101000004:
        print('namespace已存在')


def space_help():
    print('Usage:  COMMAND  [Option]')
    print('Common Commands: \n'
          'list                  Display namespace list\n'
          'create [namespace]    Create a namespace and  The [namespace] represents the name you need to create\n'
          'upload [namespace]    Upload the configuration file to the specified namespace. If the [namespace] is \n'
          '                      empty,upload it to the default namespace\n'
          'exit                  Exit Skyctl terminal')
